==> forecasting_1.01.tar.gz: forecasting/forecast/man/spline.f.Rd <==
\name{splinef}
\alias{splinef}
\title{Cubic Spline Forecast}
\usage{splinef(x, h=10, conf=c(80,95), fan=FALSE)}

\arguments{
\item{x}{a numeric vector or time series}
\item{h}{Number of periods for forecasting}
\item{conf}{Confidence level for prediction intervals.}
\item{fan}{If TRUE, conf is set to seq(50,99,by=1). This is suitable for fan plots.}
}

\description{Returns local linear forecasts and prediction
intervals using cubic smoothing splines.}

\details{The cubic smoothing spline model is equivalent to an
ARIMA(0,2,2) model but with a restricted parameter space. The
advantage of the spline model over the full ARIMA model is that
it provides a smooth historical trend as well as a linear
forecast function. Hyndman, King, Pitrun, and Billah (2002) show
that the forecast performance of the  method is hardly affected
by the restricted parameter space.}


\value{An object of class "\code{forecast}".

The function \code{summary} is used to obtain and print a summary of the
results, while the function \code{plot} produces a plot of the forecasts and prediction intervals.

The generic accessor functions \code{fitted.values} and \code{residuals} extract useful features of
the value returned by \code{meanf}.

An object of class \code{"forecast"} is a list containing at least the following elements:
\item{model}{A list containing information about the fitted model}
\item{method}{The name of the forecasting method as a character string}
\item{mean}{Point forecasts as a time series}
\item{lower}{Lower limits for prediction intervals}
\item{upper}{Upper limits for prediction intervals}
\item{conf}{The confidence values associated with the prediction intervals}
\item{x}{The original time series (either \code{object} itself or the time series used to create the model stored as \code{object}).}
\item{residuals}{Residuals from the fitted model. That is x minus fitted values.}
\item{fitted}{Fitted values (one-step forecasts)}
}

\references{Hyndman, King, Pitrun and Billah (2002) Local linear forecasts using cubic smoothing
splines. Working paper available at
\url{http://www-personal.buseco.monash.edu.au/~hyndman/papers/splinefcast.htm}.}

\seealso{\code{\link[base]{smooth.spline}},
\code{\link[stats]{arima}}, \code{\link{holt}}.}

\author{Rob J Hyndman}

\examples{fcast <- splinef(uspop,h=5)
plot(fcast)
summary(fcast)
}

\keyword{ts}

==> forecasting_1.09.tar.gz: forecasting/forecast/man/spline.f.Rd <==
\name{splinef}
\alias{splinef}
\title{Cubic Spline Forecast}
\usage{splinef(x, h=10, level=c(80,95), fan=FALSE)}

\arguments{
\item{x}{a numeric vector or time series}
\item{h}{Number of periods for forecasting}
\item{level}{Confidence level for prediction intervals.}
\item{fan}{If TRUE, level is set to seq(50,99,by=1). This is suitable for fan plots.}
}

\description{Returns local linear forecasts and prediction
intervals using cubic smoothing splines.}

\details{The cubic smoothing spline model is equivalent to an
ARIMA(0,2,2) model but with a restricted parameter space. The
advantage of the spline model over the full ARIMA model is that
it provides a smooth historical trend as well as a linear
forecast function. Hyndman, King, Pitrun, and Billah (2002) show
that the forecast performance of the  method is hardly affected
by the restricted parameter space.}


\value{An object of class "\code{forecast}".

The function \code{summary} is used to obtain and print a summary of the
results, while the function \code{plot} produces a plot of the forecasts and prediction intervals.

The generic accessor functions \code{fitted.values} and \code{residuals} extract useful features of
the value returned by \code{meanf}.

An object of class \code{"forecast"} is a list containing at least the following elements:
\item{model}{A list containing information about the fitted model}
\item{method}{The name of the forecasting method as a character string}
\item{mean}{Point forecasts as a time series}
\item{lower}{Lower limits for prediction intervals}
\item{upper}{Upper limits for prediction intervals}
\item{level}{The confidence values associated with the prediction intervals}
\item{x}{The original time series (either \code{object} itself or the time series used to create the model stored as \code{object}).}
\item{residuals}{Residuals from the fitted model. That is x minus fitted values.}
\item{fitted}{Fitted values (one-step forecasts)}
}

\references{Hyndman, King, Pitrun and Billah (2005) Local linear forecasts using cubic smoothing
splines. \emph{Australian and New Zealand Journal of Statistics}, \bold{47}(1), 87-99.
\url{http://www.robhyndman.info/papers/splinefcast.htm}.}

\seealso{\code{\link[base]{smooth.spline}},
\code{\link[stats]{arima}}, \code{\link{holt}}.}

\author{Rob J Hyndman}

\examples{fcast <- splinef(uspop,h=5)
plot(fcast)
summary(fcast)
}

\keyword{ts}
